@@ -160,17 +160,26 @@ static void handle_options(int argc, char **argv)
 	}
 }
 
-static void signal_handler(int signal)
+static void signal_handler(int signum)
 {
-	fprintf(stdout, "signal %u received\n", signal);
+	fprintf(stdout, "signal %u received\n", signum);
 
-	switch (signal) {
+	switch (signum) {
 	case SIGINT:
 		exit(0);
 		break;
 	case SIGABRT:
-		/* in case of abort, we want to obtain a talloc report
-		 * and then return to the caller, who will abort the process */
+		/* in case of abort, we want to obtain a talloc report and
+		 * then run default SIGABRT handler, who will generate coredump
+		 * and abort the process. abort() should do this for us after we
+		 * return, but program wouldn't exit if an external SIGABRT is
+		 * received.
+		 */
+		talloc_report(tall_vty_ctx, stderr);
+		talloc_report_full(tall_srv_ctx, stderr);
+		signal(SIGABRT, SIG_DFL);
+		raise(SIGABRT);
+		break;
 	case SIGUSR1:
 		talloc_report(tall_vty_ctx, stderr);
 		talloc_report_full(tall_srv_ctx, stderr);
